# namekoplus

A lightweight Python distributed microservice solution

## Command Line Tool Usage

### Checkout Command

```shell
namekoplus --help
```

### Start a middleware that nameko depends on

```shell
namekoplus start -m rabbitmq
```

### Initialize a nameko service from templates

```shell
namekoplus init --directory <dir_name> --type <template_type>
```


## Detailed Usage

See Documents: 

- [中文](https://doc.bearcatlog.com/)
- [English](https://legendary-sopapillas-e2626d.netlify.app/)